@@ -7,8 +7,9 @@ from typing import Optional
 import luddite
 import pkg_resources
 from openapi_client.api.default_api import DefaultApi
-from semver import VersionInfo
 from openapi_client.exceptions import NotFoundException, UnauthorizedException
+from semver import VersionInfo
+
 from leapcli.project import Project
 from leapcli.login import Authenticator
 from leapcli.exceptions import LoginFailed, DoctorCheckFailed
@@ -50,15 +51,17 @@ class Doctor:
 
     def _get_api(self) -> DefaultApi:
         if self._api is None:
-            self._api = Authenticator(self.project).authenticated_api()
+            self._api = Authenticator.authenticated_api()
         return self._api
 
+    @staticmethod
     @lru_cache(1)
-    def latest_cli_version(self) -> VersionInfo:
+    def latest_cli_version() -> VersionInfo:
         return VersionInfo.parse(luddite.get_version_pypi("leapcli"))
 
+    @staticmethod
     @lru_cache(1)
-    def current_cli_version(self) -> VersionInfo:
+    def current_cli_version() -> VersionInfo:
         return VersionInfo.parse(pkg_resources.get_distribution("leapcli").version)
 
     @lru_cache(1)
@@ -86,6 +89,7 @@ class Doctor:
         print_kv('Project name', self.project.detect_project())
         print_kv('Framework', self.project.framework)
         print_kv('Dataset name', self.project.detect_dataset())
+        print_kv('Bucket name', self.project.detect_bucket())
 
     def check_model(self) -> bool:
         path, _ = Push(self.project).serialize_model()
@@ -100,20 +104,20 @@ class Doctor:
         except leapcli.exceptions.ModelNotFound:
             print_kv('Model serialization', 'error')
             expected_model_path = self.project.model_py_path()
-            print(f'''\nFailed to load model configuration.
-Path: {expected_model_path}''')
+            print(f'\nFailed to load model configuration.\n'
+                  f'Path: {expected_model_path}')
         except leapcli.exceptions.ModelEntryPointNotFound:
             print_kv('Model serialization', 'error')
             expected_model_path = self.project.model_py_path()
-            print(f'''\nleap_save_model(path) function not found in model
-configuration file.
-
-Path: {expected_model_path}''')
+            print(f'\nleap_save_model(path) function not found in model\n'
+                  f'configuration file.\n'
+                  f'\n'
+                  f'Path: {expected_model_path}')
         except leapcli.exceptions.ModelNotSaved:
             print_kv('Model serialization', 'error')
             expected_model_path = self.project.model_py_path()
-            print('''\nleap_save_model(path) ran by did not save the model
-to the given .h5 file.''')
+            print('\nleap_save_model(path) ran by did not save the model\n'
+                  'to the given .h5 file.')
         except leapcli.exceptions.ModelSaveFailure as error:
             print_kv('Model serialization', 'error')
             print('\nleap_save_model(path) raised an exception.\n')
@@ -137,26 +141,23 @@ to the given .h5 file.''')
             # TODO: use the real URL once this screen is implemented
             # in the web UI
             url = f'https://{domain}/profile/api-keys'
-            print(f'''
-Credentials not found.
-
-You can generate an API key at:
-  {url}
-''')
+            print(f'\n'
+                  f'Credentials not found.\n'
+                  f'\n'
+                  f'You can generate an API key at:\n'
+                  f'  {url}\n')
             raise DoctorCheckFailed()
         try:
-            auth = Authenticator(self.project)
-            auth.load_credentials()
-            auth.key_login()
+            Authenticator.initialize(self.project)
+
             print()
-            print_kv('Logged in as', auth.user.local.email)
+            print_kv('Logged in as', Authenticator.user.local.email)
             return True
         except (UnauthorizedException, NotFoundException, LoginFailed):
-            print('''
-Login failed with the configured credentials.
-
-Try running `leap login` again.
-''')
+            print('\n'
+                  'Login failed with the configured credentials.\n'
+                  '\n'
+                  'Try running `leap login` again.\n')
             raise DoctorCheckFailed()
 
     def check_project_exist(self):
@@ -166,25 +167,29 @@ Try running `leap login` again.
             print_kv("Project found. ID", project_id)
             return
         except AssertionError:
-            print(f'''Did not find project named {self.project.project}. Please create new project using the web UI or 
-            run leap init and change to exist project.''')
+            print(f'Did not find project named {self.project.project}. Please create new project using the web UI or \n'
+                  f'            run leap init and change to exist project.')
         raise DoctorCheckFailed()
 
     def check_dataset_exist(self):
         try:
+            print('\n* Finding dataset...\n')
             dataset_id = self.project.dataset_id(self._get_api())
-            print(f'DATASET found. ID: {dataset_id}')
+            print_kv("Dataset found. ID", dataset_id)
             return
         except AssertionError:
-            print(f'''Did not find dataset named {self.project.dataset}. Please create new dataset using the web UI or 
-            run leap init and change to exist dataset.''')
+            print(f'Did not find dataset named {self.project.dataset}. Please create new dataset using the web UI or \n'
+                  f'            run leap init and change to exist dataset.')
         raise DoctorCheckFailed()
 
     def run(self):
         print(BANNER)
-        self.check_cli()
-        self.check_project()
-        self.check_creds()
-        self.check_project_exist()
-        # self.check_dataset_exist()
-        self.check_codebase()
+        try:
+            self.check_cli()
+            self.check_project()
+            self.check_creds()
+            self.check_project_exist()
+            self.check_dataset_exist()
+            self.check_codebase()
+        except DoctorCheckFailed:
+            print('Check failed.')
