@@ -6,14 +6,13 @@ import sys
 from pathlib import Path
 from typing import Tuple
 
-import openapi_client.models
 import requests
-from openapi_client.apis import DefaultApi
-# from openapi_client.model.dataset_parse_request_params import DatasetParseRequestParams
-# from openapi_client.model.parse_dataset_response import ParseDatasetResponse
+from openapi_client.model.dataset_parse_request_params import DatasetParseRequestParams
 from openapi_client.model.external_import_model_storage import ExternalImportModelStorage
+from openapi_client.model.save_dataset_version_params import SaveDatasetVersionParams
 from openapi_client.models import GetUploadSignedUrlParams, ImportNewModelParams, ImportModelType, \
     ExternalImportModelStorageResponse, GetCurrentProjectVersionParams
+
 from leapcli.project import Project
 from leapcli.login import Authenticator
 from leapcli.exceptions import ModelNotFound, ModelEntryPointNotFound, ModelSaveFailure, \
@@ -26,9 +25,9 @@ _log = logging.getLogger(__name__)
 class Push:
     def __init__(self, project: Project):
         self.project = project
-        self._auth = Authenticator(self.project)
-        self._auth.load_credentials()
-        self._api = self._auth.authenticated_api()
+
+        Authenticator.initialize(self.project)
+        self._api = Authenticator.authenticated_api()
 
     @staticmethod
     def file_sha(path: Path) -> str:
@@ -66,13 +65,23 @@ class Push:
         Push.upload_file(url, path)
         return self.start_import_job(file_name)
 
-    def parse_dataset(self):
+    def _parse_dataset(self, dataset_py_as_string: str):
         dataset_id = self.project.dataset_id(self._api)
+        params = DatasetParseRequestParams(dataset_id, is_public_bucket=False, script=dataset_py_as_string)
+        self._api.parse_dataset(params)
+
+    def _save_dataset(self, dataset_py_as_string: str):
+        dataset_id = self.project.dataset_id(self._api)
+
+        params = SaveDatasetVersionParams(dataset_id, bucket=self.project.detect_bucket(), script=dataset_py_as_string,
+                                          save_as_new=False, is_public_bucket=False, is_valid=False)
+        self._api.save_dataset_version(params)
+
+    def save_and_parse_dataset(self):
         dataset_py_path = self.project.dataset_py_path()
         with open(str(dataset_py_path), "r") as f:
             dataset_py_as_string = f.read()
-        params = DatasetParseRequestParams(dataset_id, is_public_bucket=False, script=dataset_py_as_string)
-        response: ParseDatasetResponse = self._api.parse_dataset(params)
+        self._save_dataset(dataset_py_as_string)
 
     @staticmethod
     def load_model_config_module(model_py_path: Path):
@@ -125,3 +134,6 @@ class Push:
     def run(self):
         path, content_hash = self.serialize_model()
         self.import_model(content_hash, path)
+        self.save_and_parse_dataset()
+
+        print('Push command successfully complete')
